/**! media-query-parser | Tom Golden <oss@tom.bio> (https://tom.bio) | @license MIT  */
import { ConditionNode, FeatureNode, ParserError, QueryListNode, QueryNode, ValueNode } from "./utils.js";
/**
 * creates an AST from a **media-query-list** string; parses comma-separated media queries correctly
 *
 * Important:
 *
 * - _an invalid media-query child **does not** make the media-query-list invalid_
 *  - each invalid media query child is replaced with undefined
 * - can **return** a ParserError (e.g. when there is a CSS syntax error, like an invalid string)
 *
 * @example
 * ```ts
 * console.log(parseMediaQueryList(`print, #invalid, (min-width: 1000px)`));
 * // {
 * //   n: 'query-list',
 * //   qs: [
 * //     { n: 'query', type: 'print' },
 * //     undefined,
 * //     {
 * //       n: 'query',
 * //       condition: {
 * //         n: 'condition',
 * //         op: 'and',
 * //         a: {
 * //           n: 'in-parens',
 * //           v: {
 * //             n: 'feature',
 * //             t: 'value',
 * //             f: 'min-width',
 * //             v: { n: 'dimension', v: 1000, u: 'px' }
 * //           }
 * //         }
 * //       }
 * //     }
 * //   ]
 * // }
 * ```
 */
export declare const parseMediaQueryList: (str: string) => QueryListNode | ParserError;
/**
 * creates an AST from a **media-query** string
 * @example
 * ```ts
 * console.log(parseMediaQuery(`screen and (monochrome)`));
 * // {
 * //   n: 'query',
 * //   type: 'screen',
 * //   condition: {
 * //     n: 'condition',
 * //     op: 'and',
 * //     a: {
 * //       n: 'in-parens',
 * //       v: { n: 'feature', t: 'boolean', f: 'monochrome' }
 * //     }
 * //   }
 * // }
 * ```
 */
export declare const parseMediaQuery: (str: string) => QueryNode | ParserError;
/**
 * creates an AST from a **media-condition** string
 *
 * @example
 * ```ts
 * console.log(parseMediaCondition(`((aspect-ratio > 1/2) or (monochrome))`));
 * // {
 * //   n: 'condition',
 * //   op: 'and',
 * //   a: {
 * //     n: 'in-parens',
 * //     v: {
 * //       n: 'condition',
 * //       op: 'or',
 * //       a: {
 * //         n: 'in-parens',
 * //         v: {
 * //           n: 'feature',
 * //           t: 'range',
 * //           f: 'aspect-ratio',
 * //           r: {
 * //             a: { n: 'ident', v: 'aspect-ratio' },
 * //             op: '>',
 * //             b: { n: 'ratio', l: 1, r: 2 }
 * //           }
 * //         }
 * //       },
 * //       bs: [
 * //         {
 * //           n: 'in-parens',
 * //           v: { n: 'feature', t: 'boolean', f: 'monochrome' }
 * //         }
 * //       ]
 * //     }
 * //   }
 * // }
 * ```
 */
export declare const parseMediaCondition: (str: string) => ConditionNode | ParserError;
/**
 * creates an AST from a **media-feature** string - including parentheses
 *
 * @example
 * ```ts
 * console.log(parseMediaFeature(`(min-width: 768px)`));
 * // {
 * //   n: 'feature',
 * //   t: 'value',
 * //   f: 'min-width',
 * //   v: { n: 'dimension', v: 768, u: 'px' }
 * // }
 * ```
 */
export declare const parseMediaFeature: (str: string) => FeatureNode | ParserError;
/**
 * turns an AST into an equivalent string
 *
 * @example
 * ```ts
 * console.log(stringify({
 *   n: 'query',
 *   type: 'screen',
 *   condition: {
 *     n: 'condition',
 *     op: 'and',
 *     a: {
 *       n: 'in-parens',
 *       v: { n: 'feature', t: 'boolean', f: 'monochrome' }
 *     }
 *   }
 * }));
 * // 'screen and (monochrome)'
 * ```
 */
export declare const stringify: (node: QueryListNode | QueryNode | ConditionNode | FeatureNode | ValueNode) => string;
export * from "./utils.js";
